@@ -9,13 +9,6 @@ class Dialogs : public QObject
     Q_OBJECT
 
 private:
-    static Dialogs *_instance;
-    QDialog *_quickOptionsDialog;
-    QPushButton *_backgroundColorButton;
-    QPushButton *_foregroundColorButton;
-    QPushButton *_fontButton;
-    QSlider *_alphaSlider;
-
     explicit Dialogs(QObject *parent = NULL);
 
 public:
@@ -23,6 +16,10 @@ public:
 
 public slots:
     void showQuickOptionsDialog();
+    void showBackgroundColorSelection();
+    void showForegroundColorSelection();
+    void showFontSelection();
+    void showAboutDialog();
 
 };
 
